.. Copyright 2018 Peter K. G. Williams and collaborators. Licensed under the
   Creative Commons Attribution-ShareAlike 4.0 International License.

:py:mod:`neurosynchro.grtrans`: helpers for working with ``grtrans``
====================================================================

.. automodule:: neurosynchro.grtrans
   :synopsis: helpers for working with ``grtrans``

.. currentmodule:: neurosynchro.grtrans


.. autofunction:: integrate


Low-level Interfaces to ``grtrans``
-----------------------------------

.. autofunction:: integrate_ray_formal
.. autofunction:: integrate_ray_lsoda
